/*
 *
 * CLEX File Manager
 *
 * Copyright (C) 1997-2000 Tempest s.r.o. http://www.tempest.sk
 * Copyright (C) 2001-2002 Vlado Potisk <vlado_potisk@clex.sk>
 *
 * CLEX is free software without warranty of any kind; see the
 * GNU General Public License as set out in the "COPYING" document
 * which accompanies the CLEX File Manager package.
 *
 * CLEX can be downloaded from http://www.clex.sk
 *
 */

#include <autoconf.h>

#include <stdio.h>		/* setvbuf() */
#include <termios.h>	/* struct termios */
#include <unistd.h>		/* STDIN_FILENO */

#include "tty.h"

#include "err.h"		/* err_exit() */

static struct termios text_termios, raw_termios, *ptermios = 0;

void
tty_initialize(void)
{
	if (tcgetattr(STDIN_FILENO,&text_termios) < 0)
		/* watch out, err_exit() invokes tty_reset() */
		err_exit("Cannot read the terminal settings");
	ptermios = &text_termios;

	raw_termios = text_termios;	/* struct copy */
	raw_termios.c_lflag &= ~(ECHO | ICANON | ISIG | IEXTEN);
	raw_termios.c_cc[VMIN] = 1;
	raw_termios.c_cc[VTIME] = 0;

#ifndef SETVBUF_REVERSED
	setvbuf(stdin,0,_IONBF,0);	/* input unbuffered */
	setvbuf(stdout,0,_IOFBF,0);	/* output fully buffered */
#else
	setvbuf(stdin,_IONBF,0,0);
	setvbuf(stdout,_IOFBF,0,0);
#endif
}

/* noncanonical, no echo */
void
tty_setraw(void)
{
	tcsetattr(STDIN_FILENO,TCSAFLUSH,&raw_termios);
}

void
tty_reset(void)
{
	if (ptermios)
		tcsetattr(STDIN_FILENO,TCSAFLUSH,ptermios);
}

void
tty_press_enter(void)
{
	int in;

	fputs("Press <enter> to continue. ",stdout);
	fflush(stdout);
	tty_setraw();
	while ((in = getchar()) != '\n' && in != '\r')
		;
	tty_reset();
	puts("\n----------------------------------------------");
	fflush(stdout);
}
